@@ -1,6 +1,5 @@
 #![allow(clippy::needless_return)]
 #![feature(box_syntax)]
-#![feature(map_first_last)]
 #![feature(arbitrary_enum_discriminant)]
 
 mod command;
@@ -8,7 +7,7 @@ mod errors;
 pub mod nodes;
 pub mod traits;
 
-pub use errors::{NoteError, Result};
+pub use errors::{NoteError, Result, NoteErrorKind};
 pub use nodes::{ASTKind, ASTNode, ASTNodes};
 
 pub mod utils {
