@@ -1,12 +1,12 @@
 use super::*;
-use std::cmp::Ordering;
+use std::{cmp::Ordering, ops::Range};
 
-#[derive(Clone, Eq, Ord)]
+#[derive(Clone, Eq)]
 pub struct Literal<T> {
     ///
     pub value: T,
     //
-    pub range: Option<(u32, u32)>,
+    pub range: Option<Range<usize>>,
 }
 
 impl<T: Default> Default for Literal<T> {
@@ -19,8 +19,8 @@ impl<T: Debug> Debug for Literal<T> {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         let w = &mut f.debug_struct("ASTNode");
         w.field("kind", &self.value);
-        if let Some(s) = self.range {
-            w.field("range", &format!("{}-{}", s.0, s.1));
+        if let Some(s) = &self.range {
+            w.field("range", &format!("{}-{}", s.start, s.end));
         }
         w.finish()
     }
@@ -43,3 +43,9 @@ impl<T: PartialOrd> PartialOrd for Literal<T> {
         self.value.partial_cmp(&other.value)
     }
 }
+
+impl<T: Ord> Ord for Literal<T> {
+    fn cmp(&self, other: &Self) -> Ordering {
+        self.value.cmp(&other.value)
+    }
+}
